@@ -5,6 +5,12 @@ from semantha_sdk.rest.RestClient import RestClient
 
 
 class DomainModel(SemanthaAPIEndpoint):
+    """ Endpoint for a specific domain.
+
+        References: attributes, backups, boostwords, classes, extractors,
+            formatters, instances, metadata, namedentities, regexes, relations,
+            rulefunctions, rules, synonyms
+    """
 
     def __init__(self, session: RestClient, parent_endpoint: str, domain_name: str):
         super().__init__(session, parent_endpoint)
@@ -25,12 +31,15 @@ class DomainModel(SemanthaAPIEndpoint):
         return self.__synonyms
 
 
-class Domains:
-
-    def __init__(self, session: RestClient, parent_endpoint: str):
-        self._session = session
-        self.__endpoint = parent_endpoint + "/domains"
+class Domains(SemanthaAPIEndpoint):
+    """
+        References:
+            Specific domains by name
+    """
+    @property
+    def _endpoint(self):
+        return self._parent_endpoint + "/domains"
 
     def get_one(self, domain_name: str) -> DomainModel:
         # Returns a Domain object for the given domainname, throws error if id doesn't exist
-        return DomainModel(self._session, self.__endpoint, domain_name)
+        return DomainModel(self._session, self._endpoint, domain_name)
